import React, { useState, useCallback, useEffect } from "react";
import "./App.css";
import TodoForm from "./components/TodoForm";
import TodoItem from "./components/TodoItem";
import Header from "./components/Header";
import CompletedTodos from "./components/CompletedTodos";

function App() {
  const [todos, setTodos] = useState([]);
  const [editId, setEdit] = useState(false);
  const [inputValue, setInputValue] = useState("");

  const handleEditChange = (id, text) => {
    setEdit(id);
    setInputValue(text);
  };
  const addTodo = (todo) => {
    if (!todo.text || /^\s*$/.test(todo.text)) {
      alert('Please add a Todo')
      return;
    }
    const newTodos = [todo, ...todos];
    setTodos(newTodos);
    console.log(newTodos);
  };

  const removeTodo = (id) => {
    const removedArr = [...todos].filter((todoId) => todoId.id !== id);
    setTodos(removedArr);
  };

  const completeTodo = (id) => {
    const updatedTodos = todos.map((todo) => {
      if (todo.id === id) {
        todo.status = !todo.status;
      }
      return todo;
    });
    setTodos(updatedTodos);
  };

  const editTodo = (id, text) => {
    const editTodos = todos.map((todo) => {
      if (todo.id === id) {
        todo.text = text;
      }
      return todo;
    });
    setTodos(editTodos);
    setEdit(false);
  };

  const escFunction = useCallback((event) => {
    if (event.keyCode === 27) {
      console.log("esc");
      return editTodo();
    }
  });

  useEffect(() => {
    document.addEventListener("keydown", escFunction);

    return () => {
      document.removeEventListener("keydown", escFunction);
    };
  }, [escFunction]);

  return (
    <>
      <div className='task-main'>

        <Header todos={todos} />

        <TodoItem />

        <TodoForm onSubmit={addTodo} />

        <h4 style={{ textAlign: 'center', marginBottom: '10px' }}>Completed Todos</h4>

        <CompletedTodos todos={todos}
          completeTodo={completeTodo}
          removeTodo={removeTodo} />
          
      </div>

    </>
  );
}

export default App;